Learn R Programming

wintime (version 1.0.0)

EWTP: Expected win time against trial population

Description

Calculates the combined arm state space probabilities using a Markov model or a Kaplan-Meier model (recommended). This function uses these probabilities to compare each participant's clinical state to a distribution of combined arm states.

Usage

EWTP(
  n,
  m,
  nunique,
  maxfollow,
  untimes,
  Time,
  Delta,
  dist,
  markov_ind,
  cov,
  trt,
  max_time_inc
)

Value

A list containing: The estimated treatment effect from the linear regression model, the variance, the Z-statistic, the components of the treatment effect, the variance of the components, and the maximum time used in comparisons.

Arguments

n

The total number of trial participants.

m

The number of events in the hierarchy.

nunique

The number of unique combined arm event times (returned from wintime::markov() or wintime::km()).

maxfollow

The max combined arm follow up time (days) (returned from wintime::markov() or wintime::km()).

untimes

A vector containing unique combined arm event times (days) (returned from wintime::markov() or wintime::km()).

Time

A m x n matrix of event times (days). Rows should represent events and columns should represent participants. Rows should be in increasing order of clinical severity.

Delta

A m x n matrix of event indicators Rows should represent events and columns should represent participants. Rows should be in increasing order of clinical severity.

dist

A matrix of combined arm state probabilities (returned from wintime::markov() or wintime::km()).

markov_ind

An indicator of the model type used (1 for Markov, 0 for Kaplan-Meier).

cov

A n x p matrix of covariate values, where p is the number of covariates.

trt

A vector of length n containing treatment arm indicators (1 for treatment, 0 for control).

max_time_inc

Optional. Maximal time increment for updating multi-state distribution when parametric exponential extension models are used. If unspecified, updates done at each event time in combined trial.