Calculates the state space probabilities using a Kaplan-Meier model (recommended) or a Markov model. This function uses these probabilities to compare both arms and calculate the expected win time of the treatment arm up to a given time point.
RMT(
m,
Time,
Delta,
trt,
time_restriction,
dist_state0,
dist_state1,
unique_event_times0,
unique_event_times1,
nunique_event_times0,
nunique_event_times1,
maxfollow0,
maxfollow1,
max_time_inc
)A list containing: The restricted mean survival in favor of the treatment arm, the components of the treatment effect, and the maximum time used in comparisons.
The number of events in the hierarchy.
A m x n matrix of event times (days). Rows should represent events and columns should represent participants. Rows should be in increasing order of clinical severity.
A m x n matrix of event indicators Rows should represent events and columns should represent participants. Rows should be in increasing order of clinical severity.
A vector containing treatment arm indicators (1 for treatment, 0 for control).
The cutoff time point (days) for the calculation.
A matrix of control arm state probabilities (returned from wintime::km() or wintime::markov()).
A matrix of treatment arm state probabilities (returned from wintime::km() or wintime::markov()).
A vector of unique control arm event times (days) (returned from wintime::km() or wintime::markov()).
A vector of unique treatment arm event times (days) (returned from wintime::km() or wintime::markov()).
The number of unique control arm event times (returned from wintime::km() or wintime::markov()).
The number of unique treatment arm event times (returned from wintime::km() or wintime::markov()).
The max control arm time (days) for valid nonparametric state space estimation (returned from wintime::markov() or wintime::km()).
The max trt arm time (days) for valid nonparametric state space estimation (returned from wintime::markov() or wintime::km()).
Optional. Maximal time increment for updating multi-state distribution when parametric exponential extension models are used. If unspecified, updates done at each event time in combined trial.